pub enum IncomingPacketError<E: Error> {
Undecodable(E),
Overloaded(E),
ProcessingError(OffchainPublicKey, E),
InvalidTicket(OffchainPublicKey, TicketValidationError),
}Expand description
Error that can occur when processing an incoming packet.
Variants
Undecodable(E)
Packet is not decodable.
Such errors are fatal and therefore the packet cannot be acknowledged.
Overloaded(E)
Packet dropped due to local resource exhaustion (not sender’s fault).
ProcessingError(OffchainPublicKey, E)
Packet is decodable but cannot be processed due to other reasons.
Such errors are protocol-related and packets must be acknowledged.
InvalidTicket(OffchainPublicKey, TicketValidationError)
Packet is decodable, but the ticket is invalid.
Implementations
Sourceimpl<E: Error> IncomingPacketError<E>
impl<E: Error> IncomingPacketError<E>
Sourcepub const fn is_undecodable(&self) -> bool
pub const fn is_undecodable(&self) -> bool
Returns true if the enum is IncomingPacketError::Undecodable otherwise false
Sourcepub const fn is_overloaded(&self) -> bool
pub const fn is_overloaded(&self) -> bool
Returns true if the enum is IncomingPacketError::Overloaded otherwise false
Sourcepub const fn is_processing_error(&self) -> bool
pub const fn is_processing_error(&self) -> bool
Returns true if the enum is IncomingPacketError::ProcessingError otherwise false
Sourcepub const fn is_invalid_ticket(&self) -> bool
pub const fn is_invalid_ticket(&self) -> bool
Returns true if the enum is IncomingPacketError::InvalidTicket otherwise false
Sourceimpl<E: Error> IncomingPacketError<E>
impl<E: Error> IncomingPacketError<E>
pub fn try_as_undecodable(self) -> Option<E>
pub const fn try_as_undecodable_ref(&self) -> Option<&E>
pub fn try_as_undecodable_mut(&mut self) -> Option<&mut E>
pub fn try_as_overloaded(self) -> Option<E>
pub const fn try_as_overloaded_ref(&self) -> Option<&E>
pub fn try_as_overloaded_mut(&mut self) -> Option<&mut E>
pub fn try_as_processing_error(self) -> Option<(OffchainPublicKey, E)>
pub const fn try_as_processing_error_ref( &self, ) -> Option<(&OffchainPublicKey, &E)>
pub fn try_as_processing_error_mut( &mut self, ) -> Option<(&mut OffchainPublicKey, &mut E)>
pub fn try_as_invalid_ticket( self, ) -> Option<(OffchainPublicKey, TicketValidationError)>
pub const fn try_as_invalid_ticket_ref( &self, ) -> Option<(&OffchainPublicKey, &TicketValidationError)>
pub fn try_as_invalid_ticket_mut( &mut self, ) -> Option<(&mut OffchainPublicKey, &mut TicketValidationError)>