IncomingFinalPacket

Struct IncomingFinalPacket 

pub struct IncomingFinalPacket {
    pub packet_tag: PacketTag,
    pub previous_hop: OffchainPublicKey,
    pub sender: HoprPseudonym,
    pub replied_on_surb: Option<HoprSurbId>,
    pub plain_text: Box<[u8]>,
    pub ack_key: HalfKey,
    pub info: AuxiliaryPacketInfo,
}
An incoming packet with a payload intended for us.

Fields

packet_tag: PacketTag

Packet tag.

previous_hop: OffchainPublicKey

Offchain public key of the previous hop.

sender: HoprPseudonym

Sender pseudonym.

replied_on_surb: Option<HoprSurbId>

SURB this packet was a reply on, when it was one.

None for a packet that was not sent using one of our SURBs. Surfaced because decoding already resolves the sender id to find the reply opener, so the id is known here and nowhere later.

plain_text: Box<[u8]>

Plain text payload of the packet.

ack_key: HalfKey

Acknowledgement to be sent to the previous hop.

info: AuxiliaryPacketInfo

Miscellaneous information about the packet.